@@ -10,13 +10,13 @@ logger = logging.getLogger(__name__)
 
 
 class Framework:
-    def __init__(self, static_folder: str, static_url_path: str, log_level=logging.INFO):
+    def __init__(self, static_folder: str, static_url_path: str, host: str = "localhost", port: int = 80, log_level=logging.INFO):
         logging.getLogger("web_framework_v2").setLevel(log_level)
 
         self._static_folder = static_folder
         self._static_url_path = static_url_path
         self._active = False
-        self._http_server = HttpServer(self)
+        self._http_server = HttpServer(self, host, port)
         self._endpoint_map = EndpointMap()
 
     def start(self):
